from ...utils.abbreviated_enum import AbbreviatedEnum


class MACPAccessType(AbbreviatedEnum):
    catch_basin = ("Catch Basin", "ACB")
    cleanout_house = ("Cleanout House", "ACOH")
    cleanout_mainline = ("Cleanout Mainline", "ACOM")
    cleanout_property = ("Cleanout Property", "ACOP")
    junction_box = ("Junction Box", "AJB")
    meter = ("Meter", "AM")
    manhole = ("Manhole", "AMH")
    other_special_structure = ("Other Special Structure", "AOC")
    wastewater_access = ("Wastewater Access", "AWA")
    wet_well = ("Wet well", "AWW")
